==> free-sa-1.3.4.tar.gz: free-sa-1.3.4/src/reports/r_efficiency.c <==
#include "global.h"


void ReportProxyEfficiency(void) {
    FILE *PER;
    short int i;
    const char *codes[602], *t = NULL;


    memset(codes, 0, sizeof(codes));
    switch (LogFormats[cfg.LogFormat].Class) {
	case PROXY:
	case WWW:
		codes[000] = "SQUID2x: Status None (UDP traffic or other error)";
	        codes[100] = "RFC2616: Continue";
	        codes[101] = "RFC2616: Switching Protocols";
	        codes[102] = "RFC2518: Processing";
	        codes[200] = "RFC2616: OK";
	        codes[201] = "RFC2616: Created";
	        codes[202] = "RFC2616: Accepted";
	        codes[203] = "RFC2616: Non-Authoritative Information";
	        codes[204] = "RFC2616: No Content";
	        codes[205] = "RFC2616: Reset Content";
	        codes[206] = "RFC2616: Partial Content";
	        codes[207] = "RFC2518: Multi-Status";
	        codes[300] = "RFC2616: Multiple Choices";
	        codes[301] = "RFC2616: Moved Permanently";
	        codes[302] = "RFC2616: Found";
	        codes[303] = "RFC2616: See Other";
	        codes[304] = "RFC2616: Not Modified";
	        codes[305] = "RFC2616: Use Proxy";
	        codes[307] = "RFC2616: Temporary Redirect";
	        codes[400] = "RFC2616: Bad Request";
	        codes[401] = "RFC2616: Unauthorized";
	        codes[402] = "RFC2616: Payment Required";
	        codes[403] = "RFC2616: Forbidden";
	        codes[404] = "RFC2616: Not Found";
	        codes[405] = "RFC2616: Method Not Allowed";
	        codes[406] = "RFC2616: Not Acceptable";
	        codes[407] = "RFC2616: Proxy Authentication Required";
	        codes[408] = "RFC2616: Request Timeout";
	        codes[409] = "RFC2616: Conflict";
	        codes[410] = "RFC2616: Gone";
	        codes[411] = "RFC2616: Length Required";
	        codes[412] = "RFC2616: Precondition Failed";
	        codes[413] = "RFC2616: Request Entity Too Large";
	        codes[414] = "RFC2616: Request-URI Too Large";
	        codes[415] = "RFC2616: Unsupported Media Type";
		codes[422] = "RFC2518: Unprocessable Entity";
	        codes[423] = "RFC2518: Locked";
	        codes[424] = "RFC2518: Failed Dependency";
	        codes[500] = "RFC2616: Internal Server Error";
	        codes[501] = "RFC2616: Not Implemented";
	        codes[502] = "RFC2616: Bad Gateway";
	        codes[503] = "RFC2616: Service Unavailable";
	        codes[504] = "RFC2616: Gateway Timeout";
	        codes[505] = "RFC2616: HTTP Version Not Supported";
	        codes[507] = "RFC2518: Insufficient Storage";
	        codes[600] = "SQUID2x: Header parsing error";
	        codes[601] = "SQUID2x: Header too large to process";
		break;
	case MAIL:
		codes[211] = "RFC2821: System status, or system help reply";
		codes[214] = "RFC2821: Help message";
		codes[220] = "RFC2821: Service ready";
		codes[221] = "RFC2821: Service closing transmission channel";
		codes[250] = "RFC2821: Requested mail action okay, completed";
		codes[251] = "RFC2821: User not local; will forward to forward-path";
		codes[252] = "RFC2821: Cannot VRFY user, but will accept message and attempt delivery";
		codes[354] = "RFC2821: Start mail input; end with <CRLF>.<CRLF>";
		codes[421] = "RFC2821: Service not available, closing transmission channel";
		codes[450] = "RFC2821: Requested mail action not taken: mailbox unavailable";
		codes[451] = "RFC2821: Requested action aborted: local error in processing";
		codes[452] = "RFC2821: Requested action not taken: insufficient system storage";
		codes[500] = "RFC2821: Syntax error, command unrecognized";
		codes[501] = "RFC2821: Syntax error in parameters or arguments";
		codes[502] = "RFC2821: Command not implemented";
		codes[503] = "RFC2821: Bad sequence of commands";
		codes[504] = "RFC2821: Command parameter not implemented";
		codes[550] = "RFC2821: Requested action not taken: mailbox unavailable";
		codes[551] = "RFC2821: User not local; please try forward-path";
		codes[552] = "RFC2821: Requested mail action aborted: exceeded storage allocation";
		codes[553] = "RFC2821: Requested action not taken: mailbox name not allowed";
		codes[554] = "RFC2821: Transaction failed or no SMTP service here";
		codes[557] = "NORFC: Requested action not taken: client host rejected";
		break;
	case FTP:
		codes[110] = "RFC959: Restart marker reply";
		codes[120] = "RFC959: Service ready in nnn minutes";
		codes[125] = "RFC959: Data connection already open; transfer starting";
		codes[150] = "RFC959: File status okay; about to open data connection";
		codes[200] = "RFC959: Command okay";
		codes[202] = "RFC959: Command not implemented, superfluous at this site";
		codes[211] = "RFC959: System status, or system help reply";
		codes[212] = "RFC959: Directory status";
		codes[213] = "RFC959: File status";
		codes[214] = "RFC959: Help message";
		codes[215] = "RFC959: NAME system type";
		codes[220] = "RFC959: Service ready for new user";
		codes[221] = "RFC959: Service closing control connection";
		codes[225] = "RFC959: Data connection open; no transfer in progress";
		codes[226] = "RFC959: Closing data connection";
		codes[227] = "RFC959: Entering Passive Mode";
		codes[230] = "RFC959: User logged in, proceed";
		codes[250] = "RFC959: Requested file action okay, completed";
		codes[257] = "RFC959: PATHNAME created";
		codes[331] = "RFC959: User name okay, need password";
		codes[332] = "RFC959: Need account for login";
		codes[350] = "RFC959: Requested file action pending further information";
		codes[421] = "RFC959: Service not available, closing control connection";
		codes[425] = "RFC959: Can't open data connection";
		codes[426] = "RFC959: Connection closed; transfer aborted";
		codes[450] = "RFC959: Requested file action not taken";
		codes[451] = "RFC959: Requested action aborted: local error in processing";
		codes[452] = "RFC959: Requested action not taken";
		codes[500] = "RFC959: Syntax error, command unrecognized";
		codes[501] = "RFC959: Syntax error in parameters or arguments";
		codes[502] = "RFC959: Command not implemented";
		codes[503] = "RFC959: Bad sequence of commands";
		codes[504] = "RFC959: Command not implemented for that parameter";
		codes[530] = "RFC959: Not logged in";
		codes[532] = "RFC959: Need account for storing files";
		codes[550] = "RFC959: Requested action not taken";
		codes[551] = "RFC959: Requested action aborted: page type unknown";
		codes[552] = "RFC959: Requested file action aborted";
		codes[553] = "RFC959: Requested action not taken";
		break;
    }
    
    all[4].Count = all[0].Count - all[1].Count - all[2].Count - all[3].Count;
    all[4].Bytes = all[0].Bytes - all[1].Bytes - all[2].Bytes - all[3].Bytes;
    all[4].Seconds = all[0].Seconds - all[1].Seconds - all[2].Seconds - all[3].Seconds;
    
    allmBytes[0] = SAmax(SAmax(SAmax(allmBytes[1], allmBytes[2]), allmBytes[3]), allmBytes[4]);
    allmSeconds[0] = SAmax(SAmax(SAmax(allmSeconds[1], allmSeconds[2]), allmSeconds[3]), allmSeconds[4]);
    
    all[0].Seconds /= 1000.0;
    all[1].Seconds /= 1000.0;
    all[2].Seconds /= 1000.0;
    all[3].Seconds /= 1000.0;
    all[4].Seconds /= 1000.0;

    PER = SAfopenH("../", 'r', loc->PEfficiency, NULL, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.PERname);
    
    SAfprintf(PER, "\
<tr><th rowspan=2>%s<th rowspan=2>%s<th rowspan=2>%s<th rowspan=2>%s<th colspan=2>%s/%s<th colspan=2>%s/%s\n\
<tr><th>%s<th>%s<th>%s<th>%s\n\
",
    loc->TrafType, loc->Connections, loc->Bytes, loc->Seconds, loc->Bytes, loc->Connections, loc->Seconds, loc->Connections,
    loc->AVERAGE, loc->MAXIMUM, loc->AVERAGE, loc->MAXIMUM);

    for (i = 0; i < 5; i++) if (all[i].Count) {
	    switch (i) {
		case 0:	t = loc->Served; break;
		case 1: t = loc->TT[PDN]; break;
		case 2: t = loc->Cashed; break;
		case 3: t = loc->OthLocal; break;
		case 4: t = loc->Actual; break;
	    }
	    
	    SAfprintf(PER, "<tr><td class=lt>%s<td>%'d<td>%'.0f<td>%'.0f<td>%'.0f<td>%'.0f<td>%.4f<td>%.4f\n",
		    t, all[i].Count, all[i].Bytes, all[i].Seconds, all[i].Bytes/all[i].Count, allmBytes[i], all[i].Seconds/all[i].Count, allmSeconds[i] / 1000.0);
	}

    SAfprintf(PER, "\
<tr><td class=el>\n\
\t</table>\n\
\t<table cellpadding=0 cellspacing=1>\n\
<tr><th colspan=2>%s<th>%s<th>%s<th>%s\n\
", 
	    loc->Code, loc->Connections, loc->Bytes, loc->Seconds);
    
    for (i = 0; i < 602; i++) 
	if (ec[i].Count) SAfprintf(PER, "<tr><td>%03d<td class=lt>%s<td>%'d<td>%'.0f<td>%'.0f\n", i, (codes[i]) ? codes[i] : "Unknown", ec[i].Count, ec[i].Bytes, ec[i].Seconds / 1000.0);
    
    SAfcloseH(PER, icfg.PERname);
}

==> free-sa-1.4.3.tar.gz: free-sa-1.4.3/src/reports/r_efficiency.c <==
#include "global.h"


void ReportProxyEfficiency(void) {
    FILE *PER;
    short int i;
    const char *codes[CODESSIZE], *t = NULL;


    memset(codes, 0, sizeof(codes));
    switch (LogFormats[cfg.LogFormat].Class) {
	case PROXY:
	case WWW:
		codes[000] = "SQUID2x: Status None (UDP traffic or other error)";
	        codes[100] = "RFC2616: Continue";
	        codes[101] = "RFC2616: Switching Protocols";
	        codes[102] = "RFC2518: Processing";
	        codes[200] = "RFC2616: OK";
	        codes[201] = "RFC2616: Created";
	        codes[202] = "RFC2616: Accepted";
	        codes[203] = "RFC2616: Non-Authoritative Information";
	        codes[204] = "RFC2616: No Content";
	        codes[205] = "RFC2616: Reset Content";
	        codes[206] = "RFC2616: Partial Content";
	        codes[207] = "RFC2518: Multi-Status";
	        codes[300] = "RFC2616: Multiple Choices";
	        codes[301] = "RFC2616: Moved Permanently";
	        codes[302] = "RFC2616: Found";
	        codes[303] = "RFC2616: See Other";
	        codes[304] = "RFC2616: Not Modified";
	        codes[305] = "RFC2616: Use Proxy";
	        codes[307] = "RFC2616: Temporary Redirect";
	        codes[400] = "RFC2616: Bad Request";
	        codes[401] = "RFC2616: Unauthorized";
	        codes[402] = "RFC2616: Payment Required";
	        codes[403] = "RFC2616: Forbidden";
	        codes[404] = "RFC2616: Not Found";
	        codes[405] = "RFC2616: Method Not Allowed";
	        codes[406] = "RFC2616: Not Acceptable";
	        codes[407] = "RFC2616: Proxy Authentication Required";
	        codes[408] = "RFC2616: Request Timeout";
	        codes[409] = "RFC2616: Conflict";
	        codes[410] = "RFC2616: Gone";
	        codes[411] = "RFC2616: Length Required";
	        codes[412] = "RFC2616: Precondition Failed";
	        codes[413] = "RFC2616: Request Entity Too Large";
	        codes[414] = "RFC2616: Request-URI Too Large";
	        codes[415] = "RFC2616: Unsupported Media Type";
		codes[422] = "RFC2518: Unprocessable Entity";
	        codes[423] = "RFC2518: Locked";
	        codes[424] = "RFC2518: Failed Dependency";
	        codes[500] = "RFC2616: Internal Server Error";
	        codes[501] = "RFC2616: Not Implemented";
	        codes[502] = "RFC2616: Bad Gateway";
	        codes[503] = "RFC2616: Service Unavailable";
	        codes[504] = "RFC2616: Gateway Timeout";
	        codes[505] = "RFC2616: HTTP Version Not Supported";
	        codes[507] = "RFC2518: Insufficient Storage";
	        codes[600] = "SQUID2x: Header parsing error";
	        codes[601] = "SQUID2x: Header too large to process";
		break;
	case MAIL:
		codes[211] = "RFC2821: System status, or system help reply";
		codes[214] = "RFC2821: Help message";
		codes[220] = "RFC2821: Service ready";
		codes[221] = "RFC2821: Service closing transmission channel";
		codes[250] = "RFC2821: Requested mail action okay, completed";
		codes[251] = "RFC2821: User not local; will forward to forward-path";
		codes[252] = "RFC2821: Cannot VRFY user, but will accept message and attempt delivery";
		codes[354] = "RFC2821: Start mail input; end with <CRLF>.<CRLF>";
		codes[421] = "RFC2821: Service not available, closing transmission channel";
		codes[450] = "RFC2821: Requested mail action not taken: mailbox unavailable";
		codes[451] = "RFC2821: Requested action aborted: local error in processing";
		codes[452] = "RFC2821: Requested action not taken: insufficient system storage";
		codes[500] = "RFC2821: Syntax error, command unrecognized";
		codes[501] = "RFC2821: Syntax error in parameters or arguments";
		codes[502] = "RFC2821: Command not implemented";
		codes[503] = "RFC2821: Bad sequence of commands";
		codes[504] = "RFC2821: Command parameter not implemented";
		codes[550] = "RFC2821: Requested action not taken: mailbox unavailable";
		codes[551] = "RFC2821: User not local; please try forward-path";
		codes[552] = "RFC2821: Requested mail action aborted: exceeded storage allocation";
		codes[553] = "RFC2821: Requested action not taken: mailbox name not allowed";
		codes[554] = "RFC2821: Transaction failed or no SMTP service here";
		codes[557] = "NORFC: Requested action not taken: client host rejected";
		break;
	case FTP:
		codes[110] = "RFC959: Restart marker reply";
		codes[120] = "RFC959: Service ready in nnn minutes";
		codes[125] = "RFC959: Data connection already open; transfer starting";
		codes[150] = "RFC959: File status okay; about to open data connection";
		codes[200] = "RFC959: Command okay";
		codes[202] = "RFC959: Command not implemented, superfluous at this site";
		codes[211] = "RFC959: System status, or system help reply";
		codes[212] = "RFC959: Directory status";
		codes[213] = "RFC959: File status";
		codes[214] = "RFC959: Help message";
		codes[215] = "RFC959: NAME system type";
		codes[220] = "RFC959: Service ready for new user";
		codes[221] = "RFC959: Service closing control connection";
		codes[225] = "RFC959: Data connection open; no transfer in progress";
		codes[226] = "RFC959: Closing data connection";
		codes[227] = "RFC959: Entering Passive Mode";
		codes[230] = "RFC959: User logged in, proceed";
		codes[250] = "RFC959: Requested file action okay, completed";
		codes[257] = "RFC959: PATHNAME created";
		codes[331] = "RFC959: User name okay, need password";
		codes[332] = "RFC959: Need account for login";
		codes[350] = "RFC959: Requested file action pending further information";
		codes[421] = "RFC959: Service not available, closing control connection";
		codes[425] = "RFC959: Can't open data connection";
		codes[426] = "RFC959: Connection closed; transfer aborted";
		codes[450] = "RFC959: Requested file action not taken";
		codes[451] = "RFC959: Requested action aborted: local error in processing";
		codes[452] = "RFC959: Requested action not taken";
		codes[500] = "RFC959: Syntax error, command unrecognized";
		codes[501] = "RFC959: Syntax error in parameters or arguments";
		codes[502] = "RFC959: Command not implemented";
		codes[503] = "RFC959: Bad sequence of commands";
		codes[504] = "RFC959: Command not implemented for that parameter";
		codes[530] = "RFC959: Not logged in";
		codes[532] = "RFC959: Need account for storing files";
		codes[550] = "RFC959: Requested action not taken";
		codes[551] = "RFC959: Requested action aborted: page type unknown";
		codes[552] = "RFC959: Requested file action aborted";
		codes[553] = "RFC959: Requested action not taken";
		break;
    }
    
    all[4].Count = all[0].Count - all[1].Count - all[2].Count - all[3].Count;
    all[4].Bytes = all[0].Bytes - all[1].Bytes - all[2].Bytes - all[3].Bytes;
    all[4].Seconds = all[0].Seconds - all[1].Seconds - all[2].Seconds - all[3].Seconds;
    
    allmBytes[0] = SAmax(SAmax(SAmax(allmBytes[1], allmBytes[2]), allmBytes[3]), allmBytes[4]);
    allmSeconds[0] = SAmax(SAmax(SAmax(allmSeconds[1], allmSeconds[2]), allmSeconds[3]), allmSeconds[4]);
    
    all[0].Seconds /= 1000.0;
    all[1].Seconds /= 1000.0;
    all[2].Seconds /= 1000.0;
    all[3].Seconds /= 1000.0;
    all[4].Seconds /= 1000.0;

    PER = SAfopenH("../", 'r', loc->PEfficiency, NULL, 1, "w", "%s/%s.html", icfg.ReportDir, icfg.PERname);
    
    SAfprintf(PER, "\
<tr><th rowspan=2>%s<th rowspan=2>%s<th rowspan=2>%s<th rowspan=2>%s<th colspan=2>%s/%s<th colspan=2>%s/%s\n\
<tr><th>%s<th>%s<th>%s<th>%s\n\
",
    loc->TrafType, loc->Connections, loc->Bytes, loc->Seconds, loc->Bytes, loc->Connections, loc->Seconds, loc->Connections,
    loc->AVERAGE, loc->MAXIMUM, loc->AVERAGE, loc->MAXIMUM);

    for (i = 0; i < 5; i++) if (all[i].Count) {
	    switch (i) {
		case 0:	t = loc->Served; break;
		case 1: t = loc->TT[PDN]; break;
		case 2: t = loc->Cashed; break;
		case 3: t = loc->OthLocal; break;
		case 4: t = loc->Actual; break;
	    }
	    
	    SAfprintf(PER, "<tr><td class=lt>%s<td>%'d<td>%'.0f<td>%'.0f<td>%'.0f<td>%'.0f<td>%.4f<td>%.4f\n",
		    t, all[i].Count, all[i].Bytes, all[i].Seconds, all[i].Bytes/all[i].Count, allmBytes[i], all[i].Seconds/all[i].Count, allmSeconds[i] / 1000.0);
	}

    SAfprintf(PER, "\
<tr><td class=el>\n\
\t</table>\n\
\t<table cellpadding=0 cellspacing=1>\n\
<tr><th colspan=2>%s<th>%s<th>%s<th>%s\n\
", 
	    loc->Code, loc->Connections, loc->Bytes, loc->Seconds);
    
    for (i = 0; i < CODESSIZE; i++) 
	if (ec[i].Count) SAfprintf(PER, "<tr><td>%03d<td class=lt>%s<td>%'d<td>%'.0f<td>%'.0f\n", i, (codes[i]) ? codes[i] : "Unknown", ec[i].Count, ec[i].Bytes, ec[i].Seconds / 1000.0);
    
    SAfcloseH(PER, icfg.PERname);
}
